//  Copyright 2019 Kakao Corp.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.

import Foundation
import RxKakaoSDKUser

/// 사용자 정보 조회 API 응답으로 제공되는 사용자 정보 최상위 클래스입니다. 보다 자세한 내용은 Open SDK 용 User 문서를 참고해주세요.
public struct PartnerUser : Codable {
    
    public let id: Int64
    public let properties: [String:String]?
    /// 카카오계정 정보
    /// - seealso: `PartnerAccount`
    public let kakaoAccount: PartnerAccount?
    public let groupUserToken: String?
    
    public let connectedAt : Date?
    public let synchedAt : Date?
    
    //for partner 전용.
    /// 사용자가 앱에 연결되어 있는지 여부를 나타냅니다. **자동 연결** 설정이 활성화되어 있는 경우 값이 내려오지 않으므로 앱에 연결되어 있다고 가정해도 무방합니다.
    public let hasSignedUp: Bool?
    /// 파트너용 사용자 정보
    /// - seealso: `ForPartner`
    public let forPartner: ForPartner?
}

/// 카카오계정에 등록된 사용자 개인정보를 제공합니다. 보다 자세한 내용은 Open SDK 용 Account 문서를 참고해주세요.
public struct PartnerAccount : Codable {
    
    // MARK: Fields
    
    public let profileNeedsAgreement: Bool?
    public let profile: Profile?
    
    public let emailNeedsAgreement: Bool?
    public let isEmailValid: Bool?
    public let isEmailVerified: Bool?
    public let email: String?
    
    public let ageRangeNeedsAgreement: Bool?
    public let ageRange: AgeRange?
    public let birthyaerNeedsAgreement: Bool?
    public let birthyaer: String?
    public let birthdayNeedsAgreement: Bool?
    public let birthday: String?
    public let birthdayType: BirthdayType?
    public let genderNeedsAgreement: Bool?
    public let gender: Gender?
    public let phoneNumberNeedsAgreement: Bool?
    public let phoneNumber: String?
    public let ciNeedsAgreement: Bool?
    public let ci: String?
    public let ciAuthenticatedAt: Date?
    
    public let legalNameNeedsAgreement : Bool?
    public let legalName : String?
    
    public let legalBirthDateNeedsAgreement : Bool?
    public let legalBirthDate : String?
    
    public let legalGenderNeedsAgreement : Bool?
    public let legalGender : Gender?

    //for partner 전용.
    /// 카카오톡 사용자인지 여부를 나타냅니다.
    public let isKakaotalkUser: Bool?
    /// 화면에 표시하기 위해 마스킹처리된 카카오계정의 이메일 또는 전화번호 값입니다.
    public let displayId: String?
    
}

/// 파트너용으로 제공되는 추가 정보입니다.
public struct ForPartner : Codable {
    
    /// 메시지를 전송하기 위한 고유 아이디
    ///
    /// 카카오 서비스의 회원임을 앱내에서 식별 할 수 있지만, 사용자의 계정 상태에 따라 이 정보는 바뀔 수 있습니다. 앱내의 사용자 식별자로 저장 사용되는 것은 권장하지 않습니다.
    public let uuid: String?
    
    /// 남아 있는 초대 메시지 전송 가능 횟수
    public let remainingInviteCount: Int?
    
    /// 남아있는 그룹 메시지 전송 가능 횟수
    public let remainingGroupMsgCount: Int?
}

